@@ -30,7 +30,6 @@ pub(crate) const KUBE_SYSTEM_NS: &str = "kube-system";
 const STATEHUB_CLUSTER_TOKEN_SECRET_TYPE: &str = "statehub.io/cluster-token";
 const STATEHUB_CLUSTER_TOKEN_SECRET_NAME: &str = "statehub-cluster-token";
 const STATEHUB_CLUSTER_CONFIGMAP_NAME: &str = "statehub";
-const STATEHUB_DEFAULT_CLEANUP_GRACE: &str = "600s";
 
 pub(crate) struct Kubectl {
     kubeconfig: Kubeconfig,
@@ -65,9 +64,15 @@ impl Kubectl {
     }
 
     async fn get_client(&self) -> anyhow::Result<Client> {
-        self.kubeconfig
-            .context_config(&self.context)
-            .await?
+        let context = Some(self.context.clone());
+        let options = KubeConfigOptions {
+            context,
+            ..KubeConfigOptions::default()
+        };
+        let kubeconfig = self.kubeconfig.clone();
+        Config::from_custom_kubeconfig(kubeconfig, &options)
+            .await
+            .context("Loading context from kubeconfig")?
             .try_into()
             .context("Connecting to Kubernetes cluster")
     }
@@ -111,6 +116,7 @@ impl Kubectl {
         cluster_name: &v0::ClusterName,
         default_state: &str,
         api: &str,
+        cleanup_grace: &str,
     ) -> anyhow::Result<ConfigMap> {
         let configmaps = self.namespaced_api(namespace).await?;
         let configmap = json::from_value(json::json!({
@@ -124,7 +130,7 @@ impl Kubectl {
                 "cluster-name": cluster_name,
                 "default-state": default_state,
                 "api-url": api,
-                "cleanup-grace": STATEHUB_DEFAULT_CLEANUP_GRACE,
+                "cleanup-grace": cleanup_grace,
             }
         }))?;
         let pp = self.post_params();
@@ -249,6 +255,7 @@ impl Kubectl {
         cluster_name: &v0::ClusterName,
         default_state: &str,
         api: &str,
+        cleanup_grace: &str,
     ) -> anyhow::Result<ConfigMap> {
         if self
             .delete_configmap(namespace, STATEHUB_CLUSTER_CONFIGMAP_NAME)
@@ -264,6 +271,7 @@ impl Kubectl {
             cluster_name,
             default_state,
             api,
+            cleanup_grace,
         )
         .await
     }
