@@ -223,13 +223,14 @@ or run following commands before running 'statehub register-cluster`
         kubectl: &k8s::Kubectl,
         cluster: &v0::Cluster,
         helm: &k8s::Helm,
+        cleanup_grace: &str,
     ) -> anyhow::Result<()> {
         let namespace = helm.namespace();
         let default_state = helm.default_state().unwrap_or("");
         let api = self.api.url("");
 
         kubectl
-            .store_configmap(namespace, &cluster.name, default_state, &api)
+            .store_configmap(namespace, &cluster.name, default_state, &api, cleanup_grace)
             .await?;
 
         Ok(())
