@@ -147,6 +147,9 @@ enum Command {
 
         #[structopt(help = "K8s cluster provider [default: autodetect]", long)]
         provider: Option<v0::Provider>,
+
+        #[structopt(help = "Cleanup grace time out", long, default_value = "600s")]
+        cleanup_grace: String,
     },
 
     #[structopt(about = "Unregister existing cluster", aliases = &["unregister-cl", "uc"], display_order(11))]
@@ -326,6 +329,11 @@ enum Command {
             help = "The name of the state to configure as default storage class, nothing by default"
         )]
         default_state: Option<String>,
+        #[structopt(
+            help = "The name of the state to configure as default storage class, nothing by default",
+            default_value = "600s"
+        )]
+        cleanup_grace: String,
     },
 
     #[structopt(
@@ -415,6 +423,7 @@ impl Cli {
                 namespace,
                 skip_helm,
                 provider,
+                cleanup_grace,
             } => {
                 let kubectl = if let Some(context) = name.as_deref() {
                     k8s::Kubectl::with_context(context).await?
@@ -437,7 +446,14 @@ impl Cli {
                 let claim_unowned_states = !no_state_owner;
                 let helm = k8s::Helm::new(namespace, default_state, skip_helm);
                 statehub
-                    .register_single_cluster(kubectl, provider, states, helm, claim_unowned_states)
+                    .register_single_cluster(
+                        kubectl,
+                        provider,
+                        states,
+                        helm,
+                        claim_unowned_states,
+                        cleanup_grace,
+                    )
                     .await
             }
             Command::UnregisterCluster { force, name } => {
@@ -497,9 +513,10 @@ impl Cli {
                 namespace,
                 cluster,
                 default_state,
+                cleanup_grace,
             } => {
                 statehub
-                    .setup_configmap(namespace, cluster, default_state)
+                    .setup_configmap(namespace, cluster, default_state, cleanup_grace)
                     .await
             }
             Command::ListNamespaces => statehub.list_namespaces().await,
@@ -639,6 +656,7 @@ impl StateHub {
         states: Option<Vec<v0::StateName>>,
         helm: k8s::Helm,
         claim_unowned_states: bool,
+        cleanup_grace: String,
     ) -> anyhow::Result<()> {
         let helm = if k8s::helm_is_found() {
             helm
@@ -678,7 +696,7 @@ impl StateHub {
         k8s::validate_namespace(helm.namespace()).await?;
 
         self.setup_cluster_token_helper(&cluster, &helm).await?;
-        self.setup_configmap_helper(&kubectl, &cluster, &helm)
+        self.setup_configmap_helper(&kubectl, &cluster, &helm, &cleanup_grace)
             .await?;
 
         if claim_unowned_states {
@@ -883,12 +901,19 @@ impl StateHub {
         namespace: String,
         cluster_name: v0::ClusterName,
         default_state: Option<String>,
+        cleanup_grace: String,
     ) -> anyhow::Result<()> {
         let default_state = default_state.as_deref().unwrap_or("");
         let api = self.api.url("");
         k8s::Kubectl::with_context(&cluster_name)
             .await?
-            .store_configmap(&namespace, &cluster_name, default_state, &api)
+            .store_configmap(
+                &namespace,
+                &cluster_name,
+                default_state,
+                &api,
+                &cleanup_grace,
+            )
             .await?;
 
         Ok(())
